### The following convention is used for choosing a format for the translation files:

1. Google for “Microsoft Style Guide LANGUAGE COUNTRY”.
2. Check the standard suggestions for Long Date Formats.
3. Set this as the `format` option using [pickadate’s formatting rules](http://amsul.ca/pickadate.js/date.htm#formatting-rules).

Make sure `formatSubmit` is always `yyyy/mm/dd` to ensure our servers always get the value formatted the same.